/**
 *****************************************************************************
   @example  AD7921.c
   @brief    SPI control AD7921
	Trigerring external IRQ4 sends the number of times the IRQ was triggered
   over the uart

   @version V0.1
   @author  ADI CAC
   @date   September 2013

 
              
All files for ADuCM360/361 provided by ADI, including this file, are
provided  as is without warranty of any kind, either expressed or implied.
The user assumes any and all risk from the use of this code.
It is the responsibility of the person integrating this code into an application
to ensure that the resulting application performs as required and is safe.


**/



#include <stdio.h>
#include <string.h>
#include <ADuCM360.h>

#include "UrtLib.h"
#include "ClkLib.h"
#include "WdtLib.h"
#include "SPI.h"

void UARTINIT (void);
void delay(long int);

int main (void)
{
   WdtCfg(T3CON_PRE_DIV1,T3CON_IRQ_EN,T3CON_PD_DIS); // Disable Watchdog timer resets
   
   //Disable clock to unused peripherals
   ClkDis(CLKDIS_DISSPI0CLK|CLKDIS_DISSPI1CLK|CLKDIS_DISI2CCLK|CLKDIS_DISPWMCLK|CLKDIS_DIST0CLK|CLKDIS_DIST1CLK); // Only enable clock to used blocks
   ClkCfg(CLK_CD0,CLK_HF,CLKSYSDIV_DIV2EN,CLK_UCLKCG);// Select CD0 for CPU clock with 8MHz UCLK (div2 enabled on oscillator output)
   ClkSel(CLK_CD7,CLK_CD7,CLK_CD0,CLK_CD7);           // Select CD0 for UART System clock
   
   UARTINIT();                                        // Init Uart
   Aducm360_SPI_initial();							  // Initial SPI
   WriteToAD7921ViaSPI(0);
   delay(10000);
   AD7921Data=ReadFromAD7921ViaSPI();
   delay(1000); 
   while (1)
   {
   	   UrtTx(pADI_UART,0xDA);					//flag  
	   delay(10000);
	   UrtTx(pADI_UART,AD7921Data>>8);		  //send MSB
	   delay(10000);
	   UrtTx(pADI_UART,0xDB);				   //flag 
	   delay(10000);
	   UrtTx(pADI_UART,AD7921Data);		 //send LSB
	   delay(10000);
   }
}







