/**
 *****************************************************************************
   @example  SPI.c
   @brief    GPIO simulate SPI example	by aducm360


   @version V0.1
   @author  ADI	.CAC
   @date    September 2013

              
All files for ADuCM360/361 provided by ADI, including this file, are
provided  as is without warranty of any kind, either expressed or implied.
The user assumes any and all risk from the use of this code.
It is the responsibility of the person integrating this code into an application
to ensure that the resulting application performs as required and is safe.
**/

#include <stdio.h>
#include <string.h>
#include <ADuCM360.h>

#include "SPI.h"
#include "urtlib.h"

unsigned int AD7921Data;


// Simple Delay routine
extern void delay (long int length)
{
	while (length >0)
    	length--;
}

void Aducm360_SPI_initial(void)
{
	pADI_GP1->GPCON &= 0x00;  //GP1 config as GPIO
    pADI_GP1->GPOEN = 0xfd;   //GP1.0,GP1.1 input, other bits output.
	pADI_GP1->GPPUL =0x02;
	pADI_GP1->GPSET |= 0x20;	//GP1.5 high   as_RSout  state
	pADI_GP1->GPSET |= 0x40;	//GP1.6 high   as_RSin state

}

void Aducm360_output_SCLK_high(void)
{
	 pADI_GP1->GPSET |= 0x08;	//GP1.3 high
	
}

void Aducm360_output_SCLK_low(void)
{
	 pADI_GP1->GPCLR |= 0x08;	//GP1.3 low
}

void Aducm360_output_CNV_high(void)
{
	 pADI_GP1->GPSET |= 0x10;	//GP1.4 high
	
}

void Aducm360_output_CNV_low(void)
{
	 pADI_GP1->GPCLR |= 0x10;	//GP1.4 low
}

void Aducm360_output_SDIO_high(void)
{
	 pADI_GP1->GPSET |= 0x04;	//GP1.2 high
	
}

void Aducm360_output_SDIO_low(void)
{
	 pADI_GP1->GPCLR |= 0x04;	//GP1.2 low
}

/*******************************************************************
*   Function:    WriteToAD7921ViaSPI
*   Description: write to the AD7921 via the SPI port.
*******************************************************************/
void  WriteToAD7921ViaSPI(char channel)
{
	char i;
	Aducm360_output_SCLK_low();
	delay(5000);	
	Aducm360_output_CNV_low(); 
	delay(5000);	
	for(i=0; i<16; i++)
	{
		Aducm360_output_SCLK_high();
		delay(5000);
		if(i==2)
		{
			if((channel&0xff) == 0x00)
			{
				Aducm360_output_SDIO_low();	 
			}
			else
			{
				Aducm360_output_SDIO_high();	  
			}
		}
		else
		{
			Aducm360_output_SDIO_low();
		}
	delay(5000);
	Aducm360_output_SCLK_low();
	delay(5000);  
	}
	Aducm360_output_CNV_high();	//bring CS high again
	delay(5000);
}

/*******************************************************************
*   Function:    WriteAndReadFromAD7921ViaSP
*   Description: read to the AD7921 via the SPI port.
*******************************************************************/
int ReadFromAD7921ViaSPI(void)
{
	char i;
	Aducm360_output_SCLK_high();
	delay(5000);
	Aducm360_output_CNV_low(); 
	delay(5000);	
	Aducm360_output_SCLK_low();
	pADI_GP1->GPOEN = 0x18;
	delay(5000);
	AD7921Data <<=1;
	for(i=1; i<16; i++)
	{	
		AD7921Data <<=1; 
		if(((pADI_GP1->GPIN)&0x02)== 0x02)  
         {
		 	 AD7921Data |= 0x0001; 
		 }
     	else  
         {
		 	AD7921Data &= ~0x0001;
		 }
		delay(5000);
		Aducm360_output_SCLK_high();
		delay(5000);	
		Aducm360_output_SCLK_low();	
		delay(5000);		
	  
	}
	pADI_GP1->GPOEN = 0xfd;
	Aducm360_output_CNV_high();	//bring CS high again
	delay(5000);
	return AD7921Data;
}
